@@ -14,6 +14,6 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         await codeMatcher.finish()
     codes = await getCodes()
     if isinstance(event, GroupMessageEvent):
-        await bot.send_forward_msg(group_id=event.group_id, messages=codes)  # type: ignore
+        await bot.send_group_forward_msg(group_id=event.group_id, messages=codes)  # type: ignore
     else:
-        await bot.send_forward_msg(user_id=event.user_id, messages=codes)  # type: ignore
+        await bot.send_private_forward_msg(user_id=event.user_id, messages=codes)  # type: ignore
